@@ -441,7 +441,7 @@ def query_init(start_date, features=True, targets=True, filters=None):
 
 class OracleDB_Connector:
     def __init__(self):
-        return
+        self.cx_conn = None
 
     def open(self, user_oracle = '', password_oracle = '', dsn_oracle = ''):
 
@@ -478,4 +478,9 @@ class OracleDB_Connector:
         return df
 
     def close(self):
-        self.cx_conn.close()
+        try:
+            if self.cx_conn:
+                self.cx_conn.close()
+        except Exception as exc:
+            pass
+        return
